---
# https://vitepress.dev/reference/default-theme-home-page
layout: home

hero:
  name: "Qt Material UI"
  tagline: Material 3 component library for Qt Widgets
  actions:
    - theme: brand
      text: Get Started
      link: /get-started/development-status
    - theme: alt
      text: Components Reference
      link: /components

features:
  - title: Material Design
    details: Popular open source design system
  - title: Modern UI building blocks
    details: Can be used in a variety of applications
  - title: Python Conventions
    details: Intuitive and consistent API
---
